pro AGP_to_ASCII
;
; This program reads the Latitude and Longitude data in a MISR Ancillary
; Geographic Product file and writes those parameters into ASCII files,
; with one file for each block for each parameter.
;
; Input:
; There are no input parameters to the routine.  The user is prompted for the name
; of a "listfile" using a typical file selection GUI.  The  listfile should contain
; the file names (with complete directory path) of the MISR AGP files to be
; converted to ASCII, one file name per line.  By default, the dialog for specifying
; this file begins by looking in the directory where this program resides.
;
; Output:
; One file is written for each of the 180 blocks in the orbit for each
; parameter (parameter names are GeoLatitude and GeoLongitude), in ASCII text
; format. The files are written to the directory that contains the MISR Level AGP
; file being read, and the files are named using the original file name with the
; parameter and block number appended and a .txt suffix, e.g.
;
;     MISR_AM1_AGP_P016_F01_24_GeoLatitude_Block10.txt
;
; A MISR block is dimensioned with m samples or pixels by n lines, e.g. 512 samples by
; 128 lines for these parameters, and that is the format used in the output file.
; That is, there are 128 lines of data, each containing 512 values.


fields = ["GeoLatitude","GeoLongitude"]

listfile = DIALOG_PICKFILE(TITLE="Select the list file containing MISR AGP file paths")
misrfiles = STRARR(FILE_LINES(listfile))
OPENR,ilun,listfile,/GET_LUN
READF,ilun,misrfiles
FREE_LUN,ilun

for i=0,N_ELEMENTS(misrfiles)-1 do begin
  ; get file information for building output file name
  mfile = misrfiles[i]
  mdirname = FILE_DIRNAME(mfile)
  mfilename = FILE_BASENAME(mfile,'.hdf')

  ; read the field and write it out block by block
  for j=0,N_ELEMENTS(fields)-1 do begin
    status = read_grid_field(mfile,"Standard",fields[j],data)
    for k=0,179 do begin
      ofile = mdirname + path_sep() + mfilename + $
              "_"+STRTRIM(fields[j])+"_Block"+STRTRIM(STRING(k+1),2)+".txt"
      OPENW,olun,ofile,/GET_LUN
      PRINTF,olun,data[*,*,k],FORMAT="(128(512(F11.5,1X)/))"
      FREE_LUN,olun
    endfor ; loop on blocks
  endfor; loop on fields

endfor; loop on files

end
